@@ -1,5 +1,5 @@
-# Copyright 2021-2022 Mufeed Ali
-# Copyright 2021-2022 Rafael Mardojai CM
+# Copyright 2021 Mufeed Ali
+# Copyright 2021 Rafael Mardojai CM
 # SPDX-License-Identifier: GPL-3.0-or-later
 
 from gi.repository import Gtk
@@ -8,11 +8,11 @@ from dialect.define import RES_PATH
 from dialect.settings import Settings
 
 
-@Gtk.Template(resource_path=f'{RES_PATH}/shortcuts.ui')
+@Gtk.Template(resource_path=f"{RES_PATH}/shortcuts.ui")
 class DialectShortcutsWindow(Gtk.ShortcutsWindow):
-    __gtype_name__ = 'DialectShortcutsWindow'
+    __gtype_name__ = "DialectShortcutsWindow"
 
-    translate_shortcut = Gtk.Template.Child()
+    translate_shortcut: Gtk.ShortcutsShortcut = Gtk.Template.Child()  # type: ignore
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
